from setuptools import setup
from os.path import join, dirname

setup(name='saladware',
      version='0.5.5',
      description='two bears',
      packages=['saladware'],
      author='SALAD37',
      author_email='nonemovo@gmail.com',
      zip_safe=False,
      license="MIT")


def standart(title, desc):
    embed = discord.Embed(title = title, description = desc, color = 0xffaaff, timestamp = ntx.message.created_at)
    embed.set_footer(text = ntx.author.name, icon_url = ntx.author.avatar_url)
    return embed

def init(ctx):
    global ntx
    ntx = ctx
